@@ -18,12 +18,12 @@ struct Param{
 void f12(int i0, const std::vector<std::vector<short> > &si, 
          const std::vector<int> &frq, std::vector<double> &f1, 
          std::vector<std::vector<double> > &f2, 
-         const std::vector<short> &L, bool naive, bool pcount);
+         const std::vector<short> &L, bool naive, double pcount);
 
 double pan3(std::vector<double> &peff, int nsnp, int i0, 
           const std::vector<short> &L, const std::vector<short> &ci, 
           std::vector<double> h1, const std::vector<std::vector<double> > &J1,
-          bool naive);
+          bool naive, bool lzhalf);
 
 double lnl_psl(const gsl_vector *v, void *params);
 
@@ -45,4 +45,5 @@ double pan2(int nsnp, int i0, int L, const std::vector<short> &ci,
 void invC(const std::vector<std::vector<short> > &ai, 
           const std::vector<int> &frq, const std::vector<short> &L, 
           double &E, double &lnz, std::vector<std::vector<double> > &h,
-            std::vector<std::vector<std::vector<double> > > &J, double eps);
+            std::vector<std::vector<std::vector<double> > > &J, double eps,
+            double priorCount);
